# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["PhoneNumberPurchaseParams"]


class PhoneNumberPurchaseParams(TypedDict, total=False):
    phone_number: Required[Annotated[str, PropertyInfo(alias="phoneNumber")]]
    """Phone number in E.164 format."""

    name: str
    """Optional custom name for the phone number."""
